==> coming_soon-8.x-1.0-rc1.tar.gz: coming_soon/src/Entity/Controller/SubscriberListBuilder.php <==
<?php

namespace Drupal\coming_soon\Entity\Controller;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityListBuilder;
use Drupal\Core\Url;

/**
 * Provides a list controller for content_entity_example_contact entity.
 *
 * @ingroup content_entity_example
 */
class SubscriberListBuilder extends EntityListBuilder {

  /**
   * {@inheritdoc}
   *
   * We override ::render() so that we can add our own content above the table.
   * parent::render() is where EntityListBuilder creates the table using our
   * buildHeader() and buildRow() implementations.
   */
  public function render() {
    $build['description'] = array(
      '#markup' => $this->t('The list of all the guests who subscribers during the coming soon period.'
      ),
    );
    $build['table'] = parent::render();
    return $build;
  }

  /**
   * {@inheritdoc}
   *
   * Building the header and content lines for the contact list.
   *
   * Calling the parent::buildHeader() adds a column for the possible actions
   * and inserts the 'edit' and 'delete' links as defined for the entity type.
   */
  public function buildHeader() {
    $header['id'] = $this->t('Subscriber ID');
    $header['e-mail'] = $this->t('E-mail');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    /* @var $entity \Drupal\coming_soon\Entity\Subscriber */
    $row['id'] = $entity->id();
    $row['name'] = $entity->email->value;
    return $row + parent::buildRow($entity);
  }

}

==> coming_soon-8.x-1.1.tar.gz: coming_soon/src/Entity/Controller/SubscriberListBuilder.php <==
<?php

namespace Drupal\coming_soon\Entity\Controller;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityListBuilder;

/**
 * Provides a list controller for content_entity_example_contact entity.
 *
 * @ingroup content_entity_example
 */
class SubscriberListBuilder extends EntityListBuilder {

  /**
   * {@inheritdoc}
   *
   * We override ::render() so that we can add our own content above the table.
   * parent::render() is where EntityListBuilder creates the table using our
   * buildHeader() and buildRow() implementations.
   */
  public function render() {
    $build['description'] = [
      '#markup' => $this->t('The list of all the guests who subscribers during the coming soon period.'
      ),
    ];
    $build['table'] = parent::render();
    return $build;
  }

  /**
   * {@inheritdoc}
   *
   * Building the header and content lines for the contact list.
   *
   * Calling the parent::buildHeader() adds a column for the possible actions
   * and inserts the 'edit' and 'delete' links as defined for the entity type.
   */
  public function buildHeader() {
    $header['id'] = $this->t('Subscriber ID');
    $header['e-mail'] = $this->t('E-mail');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    /* @var $entity \Drupal\coming_soon\Entity\Subscriber */
    $row['id'] = $entity->id();
    $row['name'] = $entity->email->value;
    return $row + parent::buildRow($entity);
  }

}
